<?php

/**
 * @file
 * Schema generator
 *
 * @author Markus Kalkbrenner (mkalkbrenner) | bio.logis GmbH
 *   @see http://drupal.org/user/124705
 */


/**
 * Implements hook_form().
 *
 * @param unknown_type $form_state
 * @return unknown_type
 */
function apachesolr_confgen_form($form_state) {
  $form['#submit'] = array('apachesolr_vonfgen_form_submit');

  foreach (array('1.4.x', '3.5.x') as $solr_version) {
    $form['set_' . $solr_version] = array(
      '#type' => 'fieldset',
      '#title' => t('Solr %version Configuration Download', array('%version' => $solr_version)),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );

    $form['set_' . $solr_version]['submit_schema_' . $solr_version] = array(
      '#type' => 'submit',
      '#name' => 'button|schema|' . $solr_version,
      '#value' => t('Download !file for Solr !version', array('!file' => 'schema.xml', '!version' => $solr_version)),
    );

    $form['set_' . $solr_version]['submit_solrconfig_' . $solr_version] = array(
      '#type' => 'submit',
      '#name' => 'button|solrconfig|' . $solr_version,
      '#value' => t('Download !file for Solr !version', array('!file' => 'solrconfig.xml', '!version' => $solr_version)),
    );

    $form['set_' . $solr_version]['submit_zip_' . $solr_version] = array(
      '#type' => 'submit',
      '#name' => 'button|zip|' . $solr_version,
      '#value' => t('Download all files for Solr !version as zip archive', array('!version' => $solr_version)),
    );
  }

  return $form;
}

/**
 * Implements hook_form_validate()
 *
 * @param $form
 * @param $form_state
 *
 * @return void
 */
function apachesolr_confgen_form_validate(&$form, &$form_state) {
  ob_clean();
  ob_start();
  // Seems to be a bug in core that $form_state['clicked_button']['#name'] is not always correct
  // Workaroud: Use button| prefix
  $button = '';
  foreach (array_keys($form_state['input']) as $button) {
    if (strpos($button, 'button|') === 0) {
      break;
    }
  }

  list(, $type, $solr_version) = explode('|', $button);
  $solr_version = str_replace('_', '.', $solr_version);

  switch ($type) {
    case 'schema':
    case 'solrconfig':
      $qp = apachesolr_confgen_get_original_qp($type, $solr_version);
      drupal_alter('apachesolr_confgen_' . $type, $qp, $solr_version);
      ob_end_clean();
      drupal_add_http_header('Content-Type', 'text/xml; charset=utf-8');
      drupal_add_http_header('Content-Disposition', 'attachment; filename=' . $type . '.xml');
      print $qp->find(':root')->xml();
      exit();

    case 'zip':
      exit();
  }
}
